Code documentation
==================


.. autoclass:: mptt2.enums.Position
    :members:
    :undoc-members:


.. autoclass:: mptt2.models.Tree
    :members:
    :undoc-members:


.. autoclass:: mptt2.models.Node
    :members:
    :undoc-members:


.. autoclass:: mptt2.managers.TreeManager
    :members:
    :undoc-members: